.. \_installing:

# Installing

## Pip install

To install cgul, just run the following command:

```
pip install cgul
```

The cgul `pip` package has been tested successfully with the latest versions of
its dependencies [build logs](https://github.com/PROJECT/cgul/PATH/TO/test-and-release.yml)

## Conda install

No conda package has been created yet. `pip install cgul` can be used in a conda environment.

Mixing `pip` and `conda` could create some dependencies issues,
we recommend installing as many dependencies as possible with conda,
then install cgul with `pip`,
[as recommended by the anaconda team](https://www.anaconda.com/blog/using-pip-in-a-conda-environment)

## Troubleshooting

cgul requires Python 3.7 or above. Depending on your installation,
you may need to substitute `pip` to `pip3` in the examples above.
